Index: /extensions/UserAdvManager/branches/2.20/changelog.txt.php
===================================================================
--- /extensions/UserAdvManager/branches/2.20/changelog.txt.php	(revision 11313)
+++ /extensions/UserAdvManager/branches/2.20/changelog.txt.php	(revision 11314)
@@ -256,4 +256,6 @@
 
 -- 2.20.9 : Bug fixed on installation from scratch (unable to save config)
+
+-- 2.20.10 : Bug 2324 fixed - New feature : Add [days] flag to insert maximum numbers of days between two visits set in plugin's GhostTracker in GhostTracker reminder email.
 */
 ?>
Index: /extensions/UserAdvManager/branches/2.20/language/de_DE/help/plugin.lang.php
===================================================================
--- /extensions/UserAdvManager/branches/2.20/language/de_DE/help/plugin.lang.php	(revision 11313)
+++ /extensions/UserAdvManager/branches/2.20/language/de_DE/help/plugin.lang.php	(revision 11314)
@@ -163,9 +163,4 @@
 
 // --------- Starting below: New or revised $lang ---- from version 2.20.0
-/*TODO*/$lang['UAM_gttextTitle_d'] = 'Geben Sie den gewünschten Text in die E-Mail-Erinnerung angezeigt, die Benutzer rechtzeitig, um wieder zur Galerie zu besuchen (Anm.: Der Text Fertigpen mit der Installation des Plugins ist als Beispiel vorgesehen).
-<br><br>
-Further customize the content with special inserted tags : Use <b style=&quot;color: red;&quot;>[username]</b> to automatically insert the name of the destination user of the email. Use <b style=&quot;color: red;&quot;>[mygallery]</b> to insert the title of your gallery. Use <b style=&quot;color: red;&quot;>[myurl]</b> to insert your gallery URL if set in Piwigo\'s configuration options.
-<br><br>
-Um mehrere Sprachen zu benutzen, können Sie die Extended description Plugin-Tags verwenden, wenn er aktiv ist.';
 /*TODO*/$lang['UAM_infotxtTitle_d'] = 'Geben Sie den einleitenden Text, den Sie in der Informations-E-Mail angezeigt.
 <br><br>
@@ -283,3 +278,12 @@
 /*TODO*/$lang['UAM_HidePasswTitle_d'] = 'Choose here if you want to display the password chosen by the visitor in the information email. If you enable the option, the password will then appear in clear text. If you disable the password will not appear at all.';
 // --------- End: New or revised $lang ---- from version 2.20.4
+
+
+// --------- Starting below: New or revised $lang ---- from version 2.20.10
+/*TODO*/$lang['UAM_gttextTitle_d'] = 'Geben Sie den gewünschten Text in die E-Mail-Erinnerung angezeigt, die Benutzer rechtzeitig, um wieder zur Galerie zu besuchen (Anm.: Der Text Fertigpen mit der Installation des Plugins ist als Beispiel vorgesehen).
+<br><br>
+Further customize the content with special inserted tags : Use <b style=&quot;color: red;&quot;>[username]</b> to automatically insert the name of the destination user of the email. Use <b style=&quot;color: red;&quot;>[mygallery]</b> to insert the title of your gallery. Use <b style=&quot;color: red;&quot;>[myurl]</b> to insert your gallery URL if set in Piwigo\'s configuration options. Use <b style=&quot;color: red;&quot;>[days]</b> to insert the maximum numbers of days between two visits.
+<br><br>
+Um mehrere Sprachen zu benutzen, können Sie die Extended description Plugin-Tags verwenden, wenn er aktiv ist.';
+// --------- End: New or revised $lang ---- from version 2.20.10
 ?>
Index: /extensions/UserAdvManager/branches/2.20/language/en_UK/help/plugin.lang.php
===================================================================
--- /extensions/UserAdvManager/branches/2.20/language/en_UK/help/plugin.lang.php	(revision 11313)
+++ /extensions/UserAdvManager/branches/2.20/language/en_UK/help/plugin.lang.php	(revision 11314)
@@ -163,9 +163,4 @@
 
 // --------- Starting below: New or revised $lang ---- from version 2.20.0
-$lang['UAM_gttextTitle_d'] = 'Enter the text you want to appear in the email reminder to prompt the user to return to visit your gallery (NB: The text pre-filled with the installation of the plugin is provided as an example).
-<br><br>
-Further customize the content with special inserted tags : Use <b style=&quot;color: red;&quot;>[username]</b> to automatically insert the name of the destination user of the email. Use <b style=&quot;color: red;&quot;>[mygallery]</b> to insert the title of your gallery. Use <b style=&quot;color: red;&quot;>[myurl]</b> to insert your gallery URL if set in Piwigo\'s configuration options.
-<br><br>
-To use multiple languages, you can use the Extended description plugin\'s tags if it is active.';
 $lang['UAM_infotxtTitle_d'] = 'Enter the introductory text that you want to appear in the information email.
 <br><br>
@@ -283,3 +278,12 @@
 $lang['UAM_HidePasswTitle_d'] = 'Choose here if you want to display the password chosen by the visitor in the information email. If you enable the option, the password will then appear in clear text. If you disable the password will not appear at all.';
 // --------- End: New or revised $lang ---- from version 2.20.4
+
+
+// --------- Starting below: New or revised $lang ---- from version 2.20.10
+$lang['UAM_gttextTitle_d'] = 'Enter the text you want to appear in the email reminder to prompt the user to return to visit your gallery (NB: The text pre-filled with the installation of the plugin is provided as an example).
+<br><br>
+Further customize the content with special inserted tags : Use <b style=&quot;color: red;&quot;>[username]</b> to automatically insert the name of the destination user of the email. Use <b style=&quot;color: red;&quot;>[mygallery]</b> to insert the title of your gallery. Use <b style=&quot;color: red;&quot;>[myurl]</b> to insert your gallery URL if set in Piwigo\'s configuration options. Use <b style=&quot;color: red;&quot;>[days]</b> to insert the maximum numbers of days between two visits.
+<br><br>
+To use multiple languages, you can use the Extended description plugin\'s tags if it is active.';
+// --------- End: New or revised $lang ---- from version 2.20.10
 ?>
Index: /extensions/UserAdvManager/branches/2.20/language/es_ES/help/plugin.lang.php
===================================================================
--- /extensions/UserAdvManager/branches/2.20/language/es_ES/help/plugin.lang.php	(revision 11313)
+++ /extensions/UserAdvManager/branches/2.20/language/es_ES/help/plugin.lang.php	(revision 11314)
@@ -159,9 +159,4 @@
 
 // --------- Starting below: New or revised $lang ---- from version 2.20.0
-/*TODO*/$lang['UAM_gttextTitle_d'] = 'Introduzca el texto que desea que aparezca en el recordatorio por correo electrónico para pedir al usuario volver a visitar su galería (Nota: El texto pre-llenado con la instalación del plugin se presenta como un ejemplo).
-<br><br>
-Further customize the content with special inserted tags : Use <b style=&quot;color: red;&quot;>[username]</b> to automatically insert the name of the destination user of the email. Use <b style=&quot;color: red;&quot;>[mygallery]</b> to insert the title of your gallery. Use <b style=&quot;color: red;&quot;>[myurl]</b> to insert your gallery URL if set in Piwigo\'s configuration options.
-<br><br>
-Para utilizar varios idiomas, puede utilizar las etiquetas para el plugin Extended description si está activo.';
 /*TODO*/$lang['UAM_infotxtTitle_d'] = 'Introduzca el texto de introducción que desea ver en el correo electrónico de la información.
 <br><br>
@@ -279,3 +274,12 @@
 /*TODO*/$lang['UAM_HidePasswTitle_d'] = 'Choose here if you want to display the password chosen by the visitor in the information email. If you enable the option, the password will then appear in clear text. If you disable the password will not appear at all.';
 // --------- End: New or revised $lang ---- from version 2.20.4
+
+
+// --------- Starting below: New or revised $lang ---- from version 2.20.10
+/*TODO*/$lang['UAM_gttextTitle_d'] = 'Introduzca el texto que desea que aparezca en el recordatorio por correo electrónico para pedir al usuario volver a visitar su galería (Nota: El texto pre-llenado con la instalación del plugin se presenta como un ejemplo).
+<br><br>
+Further customize the content with special inserted tags : Use <b style=&quot;color: red;&quot;>[username]</b> to automatically insert the name of the destination user of the email. Use <b style=&quot;color: red;&quot;>[mygallery]</b> to insert the title of your gallery. Use <b style=&quot;color: red;&quot;>[myurl]</b> to insert your gallery URL if set in Piwigo\'s configuration options. Use <b style=&quot;color: red;&quot;>[days]</b> to insert the maximum numbers of days between two visits.
+<br><br>
+Para utilizar varios idiomas, puede utilizar las etiquetas para el plugin Extended description si está activo.';
+// --------- End: New or revised $lang ---- from version 2.20.10
 ?>
Index: /extensions/UserAdvManager/branches/2.20/language/fr_FR/help/plugin.lang.php
===================================================================
--- /extensions/UserAdvManager/branches/2.20/language/fr_FR/help/plugin.lang.php	(revision 11313)
+++ /extensions/UserAdvManager/branches/2.20/language/fr_FR/help/plugin.lang.php	(revision 11314)
@@ -159,9 +159,4 @@
 
 // --------- Starting below: New or revised $lang ---- from version 2.20.0
-$lang['UAM_gttextTitle_d'] = 'Saisissez ici le texte qui apparaîtra dans l\'email de rappel pour inciter l\'utilisateur à revenir visiter votre galerie (NB: Le texte pré-renseigné à l\'installation du plugin est donné à titre d\'exemple).
-<br><br>
-Personnalisez encore plus le contenu avec les balises d\'insertion spéciales : Utilisez la balise <b style=&quot;color: red;&quot;>[username]</b> pour insérer automatiquement le nom de l\'utilisateur destinataire de l\'email. Utilisez la balise <b style=&quot;color: red;&quot;>[mygallery]</b> pour insérer le titre de votre galerie. Utilisez la balise <b style=&quot;color: red;&quot;>[myurl]</b> pour insérer l\'URL de votre galerie si renseigné dans les options de configuration de Piwigo.
-<br><br>
-Pour une utilisation multi-langues, vous pouvez utiliser les balises [lang] du plugin Extended Description si celui-ci est actif.';
 $lang['UAM_infotxtTitle_d'] = 'Saisissez ici le texte d\'introduction personnalisé qui apparaîtra dans l\'email d\'information.
 <br><br>
@@ -279,3 +274,12 @@
 $lang['UAM_HidePasswTitle_d'] = 'Choisissez ici si vous souhaitez faire afficher le mot de passe choisi par le visiteur dans le mail d\'information. Si vous activez l\'option, le mot de passe apparaitra alors en clair. Si vous la désactivez, le mot de passe n\'apparaitra pas du tout.';
 // --------- End: New or revised $lang ---- from version 2.20.4
+
+
+// --------- Starting below: New or revised $lang ---- from version 2.20.10
+$lang['UAM_gttextTitle_d'] = 'Saisissez ici le texte qui apparaîtra dans l\'email de rappel pour inciter l\'utilisateur à revenir visiter votre galerie (NB: Le texte pré-renseigné à l\'installation du plugin est donné à titre d\'exemple).
+<br><br>
+Personnalisez encore plus le contenu avec les balises d\'insertion spéciales : Utilisez la balise <b style=&quot;color: red;&quot;>[username]</b> pour insérer automatiquement le nom de l\'utilisateur destinataire de l\'email. Utilisez la balise <b style=&quot;color: red;&quot;>[mygallery]</b> pour insérer le titre de votre galerie. Utilisez la balise <b style=&quot;color: red;&quot;>[myurl]</b> pour insérer l\'URL de votre galerie si renseigné dans les options de configuration de Piwigo. Utilisez la balise <b style=&quot;color: red;&quot;>[days]</b> pour insérer automatiquement le nombre de jour maximum entre deux visites.
+<br><br>
+Pour une utilisation multi-langues, vous pouvez utiliser les balises [lang] du plugin Extended Description si celui-ci est actif.';
+// --------- End: New or revised $lang ---- from version 2.20.10
 ?>
Index: /extensions/UserAdvManager/branches/2.20/language/it_IT/help/plugin.lang.php
===================================================================
--- /extensions/UserAdvManager/branches/2.20/language/it_IT/help/plugin.lang.php	(revision 11313)
+++ /extensions/UserAdvManager/branches/2.20/language/it_IT/help/plugin.lang.php	(revision 11314)
@@ -157,9 +157,4 @@
 
 // --------- Starting below: New or revised $lang ---- from version 2.20.0
-/*TODO*/$lang['UAM_gttextTitle_d'] = 'Enter the text you want to appear in the email reminder to prompt the user to return to visit your gallery (NB: The text pre-filled with the installation of the plugin is provided as an example).
-<br><br>
-Further customize the content with special inserted tags : Use <b style=&quot;color: red;&quot;>[username]</b> to automatically insert the name of the destination user of the email. Use <b style=&quot;color: red;&quot;>[mygallery]</b> to insert the title of your gallery. Use <b style=&quot;color: red;&quot;>[myurl]</b> to insert your gallery URL if set in Piwigo\'s configuration options.
-<br><br>
-Per utilizzare più lingue, è possibile utilizzare i tag del plugin Extended Description, se esso è attivo.';
 /*TODO*/$lang['UAM_infotxtTitle_d'] = 'Inserisci il testo introduttivo che si desidera visualizzare nella e-mail informazioni.
 <br><br>
@@ -270,3 +265,12 @@
 /*TODO*/$lang['UAM_HidePasswTitle_d'] = 'Choose here if you want to display the password chosen by the visitor in the information email. If you enable the option, the password will then appear in clear text. If you disable the password will not appear at all.';
 // --------- End: New or revised $lang ---- from version 2.20.4
+
+
+// --------- Starting below: New or revised $lang ---- from version 2.20.10
+/*TODO*/$lang['UAM_gttextTitle_d'] = 'Enter the text you want to appear in the email reminder to prompt the user to return to visit your gallery (NB: The text pre-filled with the installation of the plugin is provided as an example).
+<br><br>
+Further customize the content with special inserted tags : Use <b style=&quot;color: red;&quot;>[username]</b> to automatically insert the name of the destination user of the email. Use <b style=&quot;color: red;&quot;>[mygallery]</b> to insert the title of your gallery. Use <b style=&quot;color: red;&quot;>[myurl]</b> to insert your gallery URL if set in Piwigo\'s configuration options. Use <b style=&quot;color: red;&quot;>[days]</b> to insert the maximum numbers of days between two visits.
+<br><br>
+Per utilizzare più lingue, è possibile utilizzare i tag del plugin Extended Description, se esso è attivo.';
+// --------- End: New or revised $lang ---- from version 2.20.10
 ?>
Index: /extensions/UserAdvManager/branches/2.20/language/lv_LV/help/plugin.lang.php
===================================================================
--- /extensions/UserAdvManager/branches/2.20/language/lv_LV/help/plugin.lang.php	(revision 11313)
+++ /extensions/UserAdvManager/branches/2.20/language/lv_LV/help/plugin.lang.php	(revision 11314)
@@ -184,9 +184,4 @@
 
 // --------- Starting below: New or revised $lang ---- from version 2.20.0
-/* TODO */$lang['UAM_gttextTitle_d'] = 'Ievadiet tekstu , ko jūs gribat atspoguļot e-pasta atgādinājumā, lai atgādinātu lietotājam apmeklēt jūsu galeriju. (NB: Spraudni instalējot, aizpildītais teksts ir piedāvāts kā paraugs).
-<br><br>
-Further customize the content with special inserted tags : Use <b style=&quot;color: red;&quot;>[username]</b> to automatically insert the name of the destination user of the email. Use <b style=&quot;color: red;&quot;>[mygallery]</b> to insert the title of your gallery. Use <b style=&quot;color: red;&quot;>[myurl]</b> to insert your gallery URL if set in Piwigo\'s configuration options.
-<br><br>
-Lai izmantotu vairākas valodas, jūs varat lietot Paplašinātā apraksta spraudņa tagus (gadījumā, ja tas ir aktīvs).';
 /* TODO */$lang['UAM_infotxtTitle_d'] = 'Ievadiet teksta, ko jūs gribat atspoguļot informācijas e-vēstulē, ievaddaļu.
 <br><br>
@@ -305,3 +300,12 @@
 /*TODO*/$lang['UAM_HidePasswTitle_d'] = 'Choose here if you want to display the password chosen by the visitor in the information email. If you enable the option, the password will then appear in clear text. If you disable the password will not appear at all.';
 // --------- End: New or revised $lang ---- from version 2.20.4
+
+
+// --------- Starting below: New or revised $lang ---- from version 2.20.10
+/* TODO */$lang['UAM_gttextTitle_d'] = 'Ievadiet tekstu , ko jūs gribat atspoguļot e-pasta atgādinājumā, lai atgādinātu lietotājam apmeklēt jūsu galeriju. (NB: Spraudni instalējot, aizpildītais teksts ir piedāvāts kā paraugs).
+<br><br>
+Further customize the content with special inserted tags : Use <b style=&quot;color: red;&quot;>[username]</b> to automatically insert the name of the destination user of the email. Use <b style=&quot;color: red;&quot;>[mygallery]</b> to insert the title of your gallery. Use <b style=&quot;color: red;&quot;>[myurl]</b> to insert your gallery URL if set in Piwigo\'s configuration options. Use <b style=&quot;color: red;&quot;>[days]</b> to insert the maximum numbers of days between two visits.
+<br><br>
+Lai izmantotu vairākas valodas, jūs varat lietot Paplašinātā apraksta spraudņa tagus (gadījumā, ja tas ir aktīvs).';
+// --------- End: New or revised $lang ---- from version 2.20.10
 ?>
Index: /extensions/UserAdvManager/branches/2.20/main.inc.php
===================================================================
--- /extensions/UserAdvManager/branches/2.20/main.inc.php	(revision 11313)
+++ /extensions/UserAdvManager/branches/2.20/main.inc.php	(revision 11314)
@@ -2,5 +2,5 @@
 /*
 Plugin Name: UserAdvManager
-Version: 2.20.9
+Version: 2.20.10
 Description: Renforcer la gestion des utilisateurs - Enforce users management
 Plugin URI: http://piwigo.org/ext/extension_view.php?eid=216

Index: /extensions/UserAdvManager/branches/2.20/include/functions.inc.php
===================================================================
--- /extensions/UserAdvManager/branches/2.20/include/functions.inc.php	(revision 11313)
+++ /extensions/UserAdvManager/branches/2.20/include/functions.inc.php	(revision 11314)
@@ -1055,5 +1055,5 @@
   if (isset($conf_UAM[17]) and $conf_UAM[17] <> '' and isset($conf_UAM[15]) and $conf_UAM[15] == 'true')
   {
     // Management of Extension flags ([username], [mygallery], [myurl])
     $patterns[] = '#\[username\]#i';
     $replacements[] = $username;
@@ -1062,4 +1062,6 @@
     $patterns[] = '#\[myurl\]#i';
     $replacements[] = $conf['gallery_url'];
+    $patterns[] = '#\[days\]#i';
+    $replacements[] = $conf_UAM[16];
 
     if (function_exists('get_user_language_desc'))
@@ -1055,5 +1055,5 @@
   if (isset($conf_UAM[17]) and $conf_UAM[17] <> '' and isset($conf_UAM[15]) and $conf_UAM[15] == 'true')
   {
-    // Management of Extension flags ([username], [mygallery], [myurl])
+    // Management of Extension flags ([username], [mygallery], [myurl], [days])
     $patterns[] = '#\[username\]#i';
     $replacements[] = $username;